@@ -1,27 +1,24 @@
-import pytest
+from __future__ import annotations
 
-from urllib.parse import urljoin, urlparse
 import shutil
 import tempfile
+from contextlib import closing
+from urllib.parse import urljoin, urlparse
 
 import django
-from django.test.utils import override_settings
+import pytest
 from django.conf import settings
-from django.contrib.staticfiles import storage, finders
-from django.core.wsgi import get_wsgi_application
+from django.contrib.staticfiles import finders, storage
 from django.core.management import call_command
+from django.core.wsgi import get_wsgi_application
+from django.test.utils import override_settings
 from django.utils.functional import empty
 
-from whitenoise.middleware import WhiteNoiseMiddleware, WhiteNoiseFileResponse
+from whitenoise.middleware import WhiteNoiseFileResponse, WhiteNoiseMiddleware
 
 from .utils import AppServer, Files
 
 
-@pytest.fixture(autouse=True, scope="module")
-def setup():
-    yield django.setup()
-
-
 def reset_lazy_object(obj):
     obj._wrapped = empty
 
@@ -30,47 +27,44 @@ def get_url_path(base, url):
     return urlparse(urljoin(base, url)).path
 
 
-@override_settings()
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def static_files():
     files = Files("static", js="app.js", nonascii="nonascii\u2713.txt")
-    settings.STATICFILES_DIRS = [files.directory]
-    return files
+    with override_settings(STATICFILES_DIRS=[files.directory]):
+        yield files
 
 
-@override_settings()
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def root_files():
     files = Files("root", robots="robots.txt")
-    settings.WHITENOISE_ROOT = files.directory
-    return files
+    with override_settings(WHITENOISE_ROOT=files.directory):
+        yield files
 
 
-@override_settings()
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def tmp():
     tmp_dir = tempfile.mkdtemp()
-    settings.STATIC_ROOT = tmp_dir
-    yield tmp_dir
+    with override_settings(STATIC_ROOT=tmp_dir):
+        yield tmp_dir
     shutil.rmtree(tmp_dir)
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def _collect_static(static_files, root_files, tmp):
     reset_lazy_object(storage.staticfiles_storage)
     call_command("collectstatic", verbosity=0, interactive=False)
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def application(_collect_static):
     return get_wsgi_application()
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def server(application):
     app_server = AppServer(application)
-    yield app_server
-    app_server.close()
+    with closing(app_server):
+        yield app_server
 
 
 def test_get_root_file(server, root_files, _collect_static):
@@ -82,9 +76,10 @@ def test_versioned_file_cached_forever(server, static_files, _collect_static):
     url = storage.staticfiles_storage.url(static_files.js_path)
     response = server.get(url)
     assert response.content == static_files.js_content
-    assert response.headers.get(
-        "Cache-Control"
-    ) == "max-age={}, public, immutable".format(WhiteNoiseMiddleware.FOREVER)
+    assert (
+        response.headers.get("Cache-Control")
+        == f"max-age={WhiteNoiseMiddleware.FOREVER}, public, immutable"
+    )
 
 
 def test_unversioned_file_not_cached_forever(server, static_files, _collect_static):
@@ -98,7 +93,7 @@ def test_unversioned_file_not_cached_forever(server, static_files, _collect_stat
 
 def test_get_gzip(server, static_files, _collect_static):
     url = storage.staticfiles_storage.url(static_files.js_path)
-    response = server.get(url)
+    response = server.get(url, headers={"Accept-Encoding": "gzip"})
     assert response.content == static_files.js_content
     assert response.headers["Content-Encoding"] == "gzip"
     assert response.headers["Vary"] == "Accept-Encoding"
@@ -125,20 +120,18 @@ def test_get_nonascii_file(server, static_files, _collect_static):
     assert response.content == static_files.nonascii_content
 
 
-@override_settings()
-@pytest.fixture(params=[True, False], scope="module")
+@pytest.fixture(params=[True, False])
 def finder_static_files(request):
     files = Files("static", js="app.js", index="with-index/index.html")
-    settings.STATICFILES_DIRS = [files.directory]
-    settings.WHITENOISE_USE_FINDERS = True
-    settings.WHITENOISE_AUTOREFRESH = request.param
-    settings.WHITENOISE_INDEX_FILE = True
-    settings.STATIC_ROOT = None
-    try:
+    with override_settings(
+        STATICFILES_DIRS=[files.directory],
+        WHITENOISE_USE_FINDERS=True,
+        WHITENOISE_AUTOREFRESH=request.param,
+        WHITENOISE_INDEX_FILE=True,
+        STATIC_ROOT=None,
+    ):
         finders.get_finder.cache_clear()
-    except AttributeError:
-        finders._finders.clear()
-    return files
+        yield files
 
 
 def test_no_content_disposition_header(server, static_files, _collect_static):
@@ -147,16 +140,16 @@ def test_no_content_disposition_header(server, static_files, _collect_static):
     assert response.headers.get("content-disposition") is None
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def finder_application(finder_static_files):
     return get_wsgi_application()
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture()
 def finder_server(finder_application):
     app_server = AppServer(finder_application)
-    yield app_server
-    app_server.close()
+    with closing(app_server):
+        yield app_server
 
 
 def test_file_served_from_static_dir(finder_static_files, finder_server):
@@ -212,9 +205,8 @@ def test_whitenoise_file_response_has_only_one_header():
 
 
 @pytest.mark.skipif(django.VERSION[:2] < (3, 1), reason="feature added in Django 3.1")
-@override_settings()
 def test_relative_static_url(server, static_files, _collect_static):
-    settings.STATIC_URL = "static/"
-    url = storage.staticfiles_storage.url(static_files.js_path)
-    response = server.get(url)
-    assert response.content == static_files.js_content
+    with override_settings(STATIC_URL="static/"):
+        url = storage.staticfiles_storage.url(static_files.js_path)
+        response = server.get(url)
+        assert response.content == static_files.js_content
